@@ -42,16 +42,18 @@ class Domain(BaseAPI):
             https://developers.digitalocean.com/#create-a-new-domain-record
 
             Args:
-
-            @type  The record type (A, MX, CNAME, etc).
-            @name  The host name, alias, or service being defined by the record
-            @data  Variable data depending on record type.
+                type: The record type (A, MX, CNAME, etc).
+                name: The host name, alias, or service being defined by the record
+                data: Variable data depending on record type.
 
             Optional Args:
-
-            @priority The priority of the host
-            @port The port that the service is accessible on
-            @weight The weight of records with the same priority
+                priority: The priority of the host
+                port: The port that the service is accessible on
+                weight: The weight of records with the same priority
+                ttl: This value is the time to live for the record, in seconds.
+                flags: An unsigned integer between 0-255 used for CAA records.
+                tag: The parameter tag for CAA records. Valid values are "issue",
+                    "issuewild", or "iodef".
         """
         data = {
             "type": kwargs.get("type", None),
@@ -60,15 +62,24 @@ class Domain(BaseAPI):
         }
 
         #  Optional Args
-        if kwargs.get("priority", None):
+        if kwargs.get("priority", None) != None:
             data['priority'] = kwargs.get("priority", None)
 
         if kwargs.get("port", None):
             data['port'] = kwargs.get("port", None)
 
-        if kwargs.get("weight", None):
+        if kwargs.get("weight", None) != None:
             data['weight'] = kwargs.get("weight", None)
 
+        if kwargs.get("ttl", None):
+            data['ttl'] = kwargs.get("ttl", 1800)
+
+        if kwargs.get("flags", None) != None:
+            data['flags'] = kwargs.get("flags", None)
+
+        if kwargs.get("tag", None):
+            data['tag'] = kwargs.get("tag", "issue")
+
         return self.get_data(
             "domains/%s/records" % self.name,
             type=POST,
