@@ -11,6 +11,7 @@ class TestLoadBalancer(BaseTest):
     def setUp(self):
         super(TestLoadBalancer, self).setUp()
         self.lb_id = '4de7ac8b-495b-4884-9a69-1050c6793cd6'
+        self.vpc_uuid = "08187eaa-90eb-40d6-a8f0-0222b28ded72"
         self.lb = digitalocean.LoadBalancer(id=self.lb_id, token=self.token)
 
     @responses.activate
@@ -43,12 +44,13 @@ class TestLoadBalancer(BaseTest):
         self.assertEqual(self.lb.health_check.port, 80)
         self.assertEqual(self.lb.sticky_sessions.type, 'none')
         self.assertEqual(self.lb.droplet_ids, [3164444, 3164445])
+        self.assertEqual(self.lb.vpc_uuid, self.vpc_uuid)
 
     @responses.activate
     def test_create_ids(self):
         data = self.load_from_file('loadbalancer/single.json')
 
-        url = self.base_url + "load_balancers/"
+        url = self.base_url + "load_balancers"
         responses.add(responses.POST,
                       url,
                       body=data,
@@ -65,7 +67,7 @@ class TestLoadBalancer(BaseTest):
                                             target_protocol='https',
                                             tls_passthrough=True)
         check = digitalocean.HealthCheck()
-        sticky = digitalocean.StickySesions(type='none')
+        sticky = digitalocean.StickySessions(type='none')
         lb = digitalocean.LoadBalancer(name='example-lb-01', region='nyc3',
                                        algorithm='round_robin',
                                        forwarding_rules=[rule1, rule2],
@@ -73,6 +75,7 @@ class TestLoadBalancer(BaseTest):
                                        sticky_sessions=sticky,
                                        redirect_http_to_https=False,
                                        droplet_ids=[3164444, 3164445],
+                                       vpc_uuid=self.vpc_uuid,
                                        token=self.token).create()
         resp_rules = lb.forwarding_rules
 
@@ -91,12 +94,13 @@ class TestLoadBalancer(BaseTest):
         self.assertEqual(lb.health_check.port, 80)
         self.assertEqual(lb.sticky_sessions.type, 'none')
         self.assertEqual(lb.droplet_ids, [3164444, 3164445])
+        self.assertEqual(lb.vpc_uuid, self.vpc_uuid)
 
     @responses.activate
     def test_create_tag(self):
         data = self.load_from_file('loadbalancer/single_tag.json')
 
-        url = self.base_url + "load_balancers/"
+        url = self.base_url + "load_balancers"
         responses.add(responses.POST,
                       url,
                       body=data,
@@ -113,7 +117,7 @@ class TestLoadBalancer(BaseTest):
                                             target_protocol='https',
                                             tls_passthrough=True)
         check = digitalocean.HealthCheck()
-        sticky = digitalocean.StickySesions(type='none')
+        sticky = digitalocean.StickySessions(type='none')
         lb = digitalocean.LoadBalancer(name='example-lb-01', region='nyc3',
                                        algorithm='round_robin',
                                        forwarding_rules=[rule1, rule2],
@@ -121,11 +125,12 @@ class TestLoadBalancer(BaseTest):
                                        sticky_sessions=sticky,
                                        redirect_http_to_https=False,
                                        tag='web',
+                                       vpc_uuid=self.vpc_uuid,
                                        token=self.token).create()
         resp_rules = lb.forwarding_rules
 
         self.assertEqual(responses.calls[0].request.url,
-                         self.base_url + 'load_balancers/')
+                         self.base_url + 'load_balancers')
         self.assertEqual(lb.id, '4de2ac7b-495b-4884-9e69-1050d6793cd4')
         self.assertEqual(lb.algorithm, 'round_robin')
         self.assertEqual(lb.ip, '104.131.186.248')
@@ -141,6 +146,7 @@ class TestLoadBalancer(BaseTest):
         self.assertEqual(lb.sticky_sessions.type, 'none')
         self.assertEqual(lb.tag, 'web')
         self.assertEqual(lb.droplet_ids, [3164444, 3164445])
+        self.assertEqual(lb.vpc_uuid, self.vpc_uuid)
 
     @responses.activate
     def test_create_exception(self):
@@ -158,7 +164,7 @@ class TestLoadBalancer(BaseTest):
                                            target_port=80,
                                            target_protocol='http')
         check = digitalocean.HealthCheck()
-        sticky = digitalocean.StickySesions(type='none')
+        sticky = digitalocean.StickySessions(type='none')
         lb = digitalocean.LoadBalancer(name='example-lb-01', region='nyc3',
                                        algorithm='round_robin',
                                        forwarding_rules=[rule],
@@ -167,6 +173,7 @@ class TestLoadBalancer(BaseTest):
                                        redirect_http_to_https=False,
                                        tag='web',
                                        droplet_ids=[123456, 789456],
+                                       vpc_uuid=self.vpc_uuid,
                                        token=self.token)
 
         with self.assertRaises(ValueError) as context:
@@ -216,10 +223,10 @@ class TestLoadBalancer(BaseTest):
         self.assertEqual(self.lb.droplet_ids, [3164444, 3164445])
         self.assertEqual(self.lb.tag, '')
         self.assertEqual(self.lb.redirect_http_to_https, False)
+        self.assertEqual(self.lb.vpc_uuid, self.vpc_uuid)
 
         data2 = self.load_from_file('loadbalancer/save.json')
-        # PUT requires slash at the end of url
-        url = '{0}load_balancers/{1}/'.format(self.base_url, self.lb_id)
+        url = '{0}load_balancers/{1}'.format(self.base_url, self.lb_id)
         responses.add(responses.PUT,
                       url,
                       body=data2,
@@ -231,11 +238,12 @@ class TestLoadBalancer(BaseTest):
         self.lb.sticky_sessions.cookie_name = 'DO_LB'
         self.lb.sticky_sessions.cookie_ttl_seconds = 300
         self.lb.droplet_ids = [34153248, 34153250]
+        self.lb.vpc_uuid = self.vpc_uuid
         res = self.lb.save()
 
         lb = digitalocean.LoadBalancer(**res['load_balancer'])
         lb.health_check = digitalocean.HealthCheck(**res['load_balancer']['health_check'])
-        lb.sticky_sessions = digitalocean.StickySesions(**res['load_balancer']['sticky_sessions'])
+        lb.sticky_sessions = digitalocean.StickySessions(**res['load_balancer']['sticky_sessions'])
         rules = list()
         for rule in lb.forwarding_rules:
             rules.append(digitalocean.ForwardingRule(**rule))
@@ -268,10 +276,11 @@ class TestLoadBalancer(BaseTest):
         self.assertEqual(lb.droplet_ids, [34153248, 34153250])
         self.assertEqual(lb.tag, '')
         self.assertEqual(lb.redirect_http_to_https, False)
+        self.assertEqual(self.lb.vpc_uuid, self.vpc_uuid)
 
     @responses.activate
     def test_destroy(self):
-        url = '{0}load_balancers/{1}/'.format(self.base_url, self.lb_id)
+        url = '{0}load_balancers/{1}'.format(self.base_url, self.lb_id)
         responses.add(responses.DELETE,
                       url,
                       status=204,
@@ -283,7 +292,7 @@ class TestLoadBalancer(BaseTest):
 
     @responses.activate
     def test_add_droplets(self):
-        url = '{0}load_balancers/{1}/droplets/'.format(self.base_url,
+        url = '{0}load_balancers/{1}/droplets'.format(self.base_url,
                                                        self.lb_id)
         responses.add(responses.POST,
                       url,
@@ -299,7 +308,7 @@ class TestLoadBalancer(BaseTest):
 
     @responses.activate
     def test_remove_droplets(self):
-        url = '{0}load_balancers/{1}/droplets/'.format(self.base_url,
+        url = '{0}load_balancers/{1}/droplets'.format(self.base_url,
                                                        self.lb_id)
         responses.add(responses.DELETE,
                       url,
@@ -315,7 +324,7 @@ class TestLoadBalancer(BaseTest):
 
     @responses.activate
     def test_add_forwarding_rules(self):
-        url = '{0}load_balancers/{1}/forwarding_rules/'.format(self.base_url,
+        url = '{0}load_balancers/{1}/forwarding_rules'.format(self.base_url,
                                                                self.lb_id)
         responses.add(responses.POST,
                       url,
@@ -348,7 +357,7 @@ class TestLoadBalancer(BaseTest):
 
     @responses.activate
     def test_remove_forwarding_rules(self):
-        url = '{0}load_balancers/{1}/forwarding_rules/'.format(self.base_url,
+        url = '{0}load_balancers/{1}/forwarding_rules'.format(self.base_url,
                                                                self.lb_id)
         responses.add(responses.DELETE,
                       url,
